@@ -1,4 +1,4 @@
-from typing import List, Tuple
+from typing import List, Tuple, Optional
 from collections import OrderedDict
 from pymoo.model.problem import Problem
 from pymoo.algorithms.nsga2 import NSGA2
@@ -55,7 +55,7 @@ def optimize(
     evaluator: FitnessEvaluator,
     free_parameters_range: "OrderedDict[str, Tuple[int, int]]",
     metrics: List[Metric],
-    execution_time: str,
+    execution_time: Optional[str],
 ) -> List[float]:
     problem = MyProblem(evaluator, free_parameters_range, metrics)
 
@@ -68,15 +68,20 @@ def optimize(
         eliminate_duplicates=True,
     )
 
-    termination = get_termination("time", execution_time)
-    res = minimize(
-        problem,
-        algorithm,
-        termination,
-        seed=1,
-        save_history=True,
-        verbose=True,
-    )
+    if execution_time:
+        termination = get_termination("time", execution_time)
+        res = minimize(
+            problem,
+            algorithm,
+            termination,
+            seed=1,
+            save_history=True,
+            verbose=True,
+        )
+    else:
+        res = minimize(
+            problem, algorithm, seed=1, save_history=True, verbose=True,
+        )
     with open("objs.pkl", "wb") as f:
         pickle.dump([res, algorithm], f)
     # with open('objs.pkl', 'rb') as f:
