@@ -23,6 +23,7 @@ from dovado_rtl.cli_utility import (
     validate_target_clock,
     validate_estimator,
     validate_nearest_distance,
+    validate_int_metrics,
 )
 import typer
 
@@ -92,6 +93,12 @@ def dovado(
         help="target clock (Mhz) on which the worst negative slack is computed,"
         + "make sure this is sufficiently large to never be reached by your design",
     ),
+    metrics: Optional[List[int]] = typer.Option(
+        None,
+        callback=validate_int_metrics,
+        help="list of integers representing selected metrics, "
+        + "wait for first synthesis/implementation if you do not know the mapping",
+    ),
 ):  # pylint: disable=too-many-arguments
     # pylint: disable=too-many-locals
     config = Configuration()
@@ -158,6 +165,7 @@ def dovado(
         incremental_mode,
         stop_step,
         list(parameters),
+        metrics,
     )
     ctx.obj = {
         "parameters": parameters,
